@@ -32,6 +32,7 @@ import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
 
 import org.apache.commons.collections4.map.LinkedMap;
+import org.apache.wicket.behavior.OutputMarkupContainerClassNameBehavior;
 import org.apache.wicket.core.util.string.ComponentStrings;
 import org.apache.wicket.markup.ComponentTag;
 import org.apache.wicket.markup.ComponentTag.IAutoComponentFactory;
@@ -761,10 +762,8 @@ public abstract class MarkupContainer extends Component implements Iterable<Comp
 	 * 
 	 * @param openTagName
 	 *            the tag to render the associated markup for
-	 * @param exceptionMessage
-	 *            message that will be used for exceptions
 	 */
-	public final void renderAssociatedMarkup(final String openTagName, final String exceptionMessage)
+	public final void renderAssociatedMarkup(final String openTagName)
 	{
 		// Get associated markup file for the Border or Panel component
 		final MarkupStream associatedMarkupStream = new MarkupStream(getMarkup(null));
@@ -773,28 +772,34 @@ public abstract class MarkupContainer extends Component implements Iterable<Comp
 		MarkupElement elem = associatedMarkupStream.get();
 		if ((elem instanceof ComponentTag) == false)
 		{
-			associatedMarkupStream.throwMarkupException("Expected the open tag. " +
-				exceptionMessage);
+			associatedMarkupStream.throwMarkupException("Expected the open tag. Markup for a "
+				+ openTagName + " component must begin a tag like '<wicket:" + openTagName + ">'");
 		}
 
 		// Check for required open tag name
 		ComponentTag associatedMarkupOpenTag = (ComponentTag)elem;
 		if (!(associatedMarkupOpenTag.isOpen() && (associatedMarkupOpenTag instanceof WicketTag)))
 		{
-			associatedMarkupStream.throwMarkupException(exceptionMessage);
+			associatedMarkupStream.throwMarkupException("Markup for a " + openTagName
+				+ " component must begin a tag like '<wicket:" + openTagName + ">'");
 		}
 
 		try
 		{
 			setIgnoreAttributeModifier(true);
+			
+			final DebugSettings.ClassOutputStrategy outputClassName = getApplication().getDebugSettings()
+					.getOutputMarkupContainerClassNameStrategy();
+			if (outputClassName == DebugSettings.ClassOutputStrategy.TAG_ATTRIBUTE)
+			{
+				associatedMarkupOpenTag.addBehavior(OutputMarkupContainerClassNameBehavior.INSTANCE);
+			}
+
 			renderComponentTag(associatedMarkupOpenTag);
 			associatedMarkupStream.next();
 
 			String className = null;
-
-			final boolean outputClassName = getApplication().getDebugSettings()
-				.isOutputMarkupContainerClassName();
-			if (outputClassName)
+			if (outputClassName == DebugSettings.ClassOutputStrategy.HTML_COMMENT)
 			{
 				className = Classes.name(getClass());
 				getResponse().write("<!-- MARKUP FOR ");
@@ -804,7 +809,7 @@ public abstract class MarkupContainer extends Component implements Iterable<Comp
 
 			renderComponentTagBody(associatedMarkupStream, associatedMarkupOpenTag);
 
-			if (outputClassName)
+			if (outputClassName == DebugSettings.ClassOutputStrategy.HTML_COMMENT)
 			{
 				getResponse().write("<!-- MARKUP FOR ");
 				getResponse().write(className);
