@@ -24,11 +24,11 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
-import javax.servlet.http.HttpServletRequest;
-
-import org.apache.commons.fileupload.FileCountLimitExceededException;
-import org.apache.commons.fileupload.FileUploadBase;
-import org.apache.commons.fileupload.FileUploadException;
+import jakarta.servlet.http.HttpServletRequest;
+import org.apache.commons.fileupload2.core.FileUploadException;
+import org.apache.commons.fileupload2.core.FileUploadByteCountLimitException;
+import org.apache.commons.fileupload2.core.FileUploadSizeException;
+import org.apache.commons.fileupload2.core.FileUploadFileCountLimitException;
 import org.apache.wicket.Component;
 import org.apache.wicket.IGenericComponent;
 import org.apache.wicket.IRequestListener;
@@ -614,7 +614,6 @@ public class Form<T> extends WebMarkupContainer
 	 * Gets the maximum size for uploads. If null, the setting
 	 * {@link org.apache.wicket.settings.ApplicationSettings#getDefaultMaximumUploadSize()} is used.
 	 *
-	 *
 	 * @return the maximum size
 	 */
 	public final Bytes getMaxSize()
@@ -651,7 +650,7 @@ public class Form<T> extends WebMarkupContainer
 	/**
 	 * Gets maximum size for each file of an upload.
 	 *
-	 * @return
+	 * @return Bytes
 	 */
 	public Bytes getFileMaxSize()
 	{
@@ -750,7 +749,7 @@ public class Form<T> extends WebMarkupContainer
 
 	/**
 	 * THIS METHOD IS NOT PART OF THE WICKET API. DO NOT ATTEMPT TO OVERRIDE OR CALL IT.
-	 *
+	 * <p>
 	 * Handles form submissions.
 	 *
 	 * @see #onFormSubmitted(IFormSubmitter)
@@ -776,7 +775,7 @@ public class Form<T> extends WebMarkupContainer
 
 	/**
 	 * THIS METHOD IS NOT PART OF THE WICKET API. DO NOT ATTEMPT TO OVERRIDE OR CALL IT.
-	 *
+	 * <p>
 	 * Handles form submissions.
 	 *
 	 * @param submitter
@@ -1522,27 +1521,27 @@ public class Form<T> extends WebMarkupContainer
 	 * <p>
 	 * Don't forget to call super.onFileUploadException(e, model) at the end of your method.
 	 *
-	 * @param e
-	 * @param model
+	 * @param e FileUploadException
+	 * @param model {@code Map<String, Object>} containing info to be interpolated into keys
 	 */
 	protected void onFileUploadException(final FileUploadException e,
 		final Map<String, Object> model)
 	{
-		if (e instanceof FileUploadBase.SizeLimitExceededException)
-		{
-			String msg = getString(UPLOAD_TOO_LARGE_RESOURCE_KEY, Model.ofMap(model));
-			error(msg);
-		}
-		else if (e instanceof FileUploadBase.FileSizeLimitExceededException)
+		if (e instanceof FileUploadByteCountLimitException)
 		{
 			String msg = getString(UPLOAD_SINGLE_FILE_TOO_LARGE_RESOURCE_KEY, Model.ofMap(model));
 			error(msg);
 		}
-		else if (e instanceof FileCountLimitExceededException)
+		else if (e instanceof FileUploadFileCountLimitException)
 		{
 			String msg = getString(UPLOAD_TOO_MANY_FILES_RESOURCE_KEY, Model.ofMap(model));
 			error(msg);
 		}
+		else if (e instanceof FileUploadSizeException)
+		{
+			String msg = getString(UPLOAD_TOO_LARGE_RESOURCE_KEY, Model.ofMap(model));
+			error(msg);
+		}
 		else
 		{
 			String msg = getString(UPLOAD_FAILED_RESOURCE_KEY, Model.ofMap(model));
@@ -1552,9 +1551,6 @@ public class Form<T> extends WebMarkupContainer
 		}
 	}
 
-	/**
-	 * @see org.apache.wicket.Component#internalOnModelChanged()
-	 */
 	@Override
 	protected void internalOnModelChanged()
 	{
